@@ -16,72 +16,28 @@ import requests
 
 from bokeh.model import Model
 
+from .config import config, panel_extension
+from .io.resources import RESOURCE_URLS
+from .reactive import ReactiveHTML
+from .template.base import BasicTemplate
+from .theme import Design
+
+BASE_DIR = pathlib.Path(__file__).parent
+BUNDLE_DIR = pathlib.Path(__file__).parent / 'dist' / 'bundled'
+
 #---------------------------------------------------------------------
 # Public API
 #---------------------------------------------------------------------
 
-def require_components():
-    """
-    Returns JS snippet to load the required dependencies in the classic
-    notebook using REQUIRE JS.
-    """
-    from .config import config
-    from .reactive import ReactiveHTML
-
-    configs, requirements, exports = [], [], {}
-    js_requires = []
-
-    from bokeh.model import Model
-    for qual_name, model in Model.model_class_reverse_map.items():
-        # We need to enable Models from Panel as well as Panel extensions
-        # like awesome_panel_extensions.
-        # The Bokeh models do not have "." in the qual_name
-        if "." in qual_name:
-            js_requires.append(model)
-
-    js_requires += list(param.concrete_descendents(ReactiveHTML).values())
-
-    for export, js in config.js_files.items():
-        name = js.split('/')[-1].replace('.min', '').split('.')[-2]
-        conf = {'paths': {name: js[:-3]}, 'exports': {name: export}}
-        js_requires.append(conf)
-
-    skip_import = {}
-    for model in js_requires:
-        if hasattr(model, '__js_skip__'):
-            skip_import.update(model.__js_skip__)
-
-        if not (hasattr(model, '__js_require__') or isinstance(model, dict)):
-            continue
-
-        if isinstance(model, dict):
-            model_require = model
-        else:
-            model_require = dict(model.__js_require__)
-
-        model_exports = model_require.pop('exports', {})
-        if not any(model_require == config for config in configs):
-            configs.append(model_require)
-
-        for req in list(model_require.get('paths', [])):
-            if isinstance(req, tuple):
-                model_require['paths'] = dict(model_require['paths'])
-                model_require['paths'][req[0]] = model_require['paths'].pop(req)
-
-            reqs = req[1] if isinstance(req, tuple) else (req,)
-            for r in reqs:
-                if r not in requirements:
-                    requirements.append(r)
-                    if r in model_exports:
-                        exports[r] = model_exports[r]
-
-    return configs, requirements, exports, skip_import
-
-def write_bundled_files(name, files, bundle_dir, explicit_dir=None, ext=None):
-    from .config import config
-
+def write_bundled_files(name, files, explicit_dir=None, ext=None):
     model_name = name.split('.')[-1].lower()
     for bundle_file in files:
+        if not bundle_file.startswith('http'):
+            dest_path = BUNDLE_DIR / name.lower() / bundle_file
+            dest_path.parent.mkdir(parents=True, exist_ok=True)
+            shutil.copyfile(BASE_DIR / 'theme' / bundle_file, dest_path)
+            continue
+
         bundle_file = bundle_file.split('?')[0]
         try:
             response = requests.get(bundle_file)
@@ -105,7 +61,7 @@ def write_bundled_files(name, files, bundle_dir, explicit_dir=None, ext=None):
         else:
             bundle_path = os.path.join(*os.path.join(*bundle_file.split('//')[1:]).split('/')[1:])
         obj_dir = explicit_dir or model_name
-        filename = bundle_dir.joinpath(obj_dir, bundle_path)
+        filename = BUNDLE_DIR.joinpath(obj_dir, bundle_path)
         filename.parent.mkdir(parents=True, exist_ok=True)
         filename = str(filename)
         if ext and not str(filename).endswith(ext):
@@ -121,8 +77,8 @@ def write_bundled_files(name, files, bundle_dir, explicit_dir=None, ext=None):
             with open(f'{filename}.map', 'w', encoding="utf-8") as f:
                 f.write(map_response.content.decode('utf-8'))
 
-def write_bundled_tarball(name, tarball, bundle_dir, module=False):
-    model_name = name.split('.')[-1].lower()
+def write_bundled_tarball(tarball, name=None, module=False):
+    model_name = name.split('.')[-1].lower() if name else ''
     try:
         response = requests.get(tarball['tar'])
     except Exception:
@@ -140,7 +96,10 @@ def write_bundled_tarball(name, tarball, bundle_dir, module=False):
             continue
         bundle_path = os.path.join(*path.split('/'))
         dest_path = tarball['dest'].replace('/', os.path.sep)
-        filename = bundle_dir.joinpath(model_name, dest_path, bundle_path)
+        if model_name:
+            filename = BUNDLE_DIR.joinpath(model_name, dest_path, bundle_path)
+        else:
+            filename = BUNDLE_DIR.joinpath(dest_path, bundle_path)
         filename.parent.mkdir(parents=True, exist_ok=True)
         fobj = tar_obj.extractfile(tarf.name)
         filename = str(filename)
@@ -158,7 +117,7 @@ def write_bundled_tarball(name, tarball, bundle_dir, module=False):
                 f.write(content)
     tar_obj.close()
 
-def write_bundled_zip(name, resource, bundle_dir):
+def write_bundled_zip(name, resource):
     try:
         response = requests.get(resource['zip'])
     except Exception:
@@ -173,7 +132,7 @@ def write_bundled_zip(name, resource, bundle_dir):
         if any(fnmatch.fnmatch(zipf, exc) for exc in exclude) or zipf.endswith('/'):
             continue
         bundle_path = path.replace('/', os.path.sep)
-        filename = bundle_dir.joinpath(name, bundle_path)
+        filename = BUNDLE_DIR.joinpath(name, bundle_path)
         filename.parent.mkdir(parents=True, exist_ok=True)
         fdata = zip_obj.read(zipf)
         filename = str(filename)
@@ -185,27 +144,99 @@ def write_bundled_zip(name, resource, bundle_dir):
                 f.write(fdata.decode('utf-8'))
     zip_obj.close()
 
-def bundle_resources(verbose=False):
-    from .config import panel_extension
-    from .io.resources import RESOURCE_URLS
-    from .reactive import ReactiveHTML
-    from .template.base import BasicTemplate
-    from .template.theme import Theme
-
-    for imp in panel_extension._imports.values():
-        if imp.startswith('panel.models'):
-            __import__(imp)
-
-    bundle_dir = pathlib.Path(__file__).parent.joinpath('dist', 'bundled')
+def write_component_resources(name, component):
+    write_bundled_files(name, list(component._resources.get('css', {}).values()), BUNDLE_DIR, 'css')
+    write_bundled_files(name, list(component._resources.get('js', {}).values()), BUNDLE_DIR, 'js')
+    js_modules = []
+    for tar_name, js_module in component._resources.get('js_modules', {}).items():
+        if tar_name not in component._resources.get('tarball', {}):
+            js_modules.append(js_module)
+    write_bundled_files(name, js_modules, 'js', ext='mjs')
+    for tarball in component._resources.get('tarball', {}).values():
+        write_bundled_tarball(tarball)
 
+def bundle_resource_urls(verbose=False, external=True):
     # Collect shared resources
     for name, resource in RESOURCE_URLS.items():
         if verbose:
             print(f'Bundling shared resource {name}.')
         if 'zip' in resource:
-            write_bundled_zip(name, resource, bundle_dir)
+            write_bundled_zip(name, resource)
         elif 'tar' in resource:
-            write_bundled_tarball(name, resource, bundle_dir)
+            write_bundled_tarball(resource, name=name)
+
+def bundle_templates(verbose=False, external=True):
+    # Bundle Template resources
+    for name, template in param.concrete_descendents(BasicTemplate).items():
+        if verbose:
+            print(f'Bundling {name} resources')
+
+        # Bundle Template._resources
+        if template._resources.get('bundle', True) and external:
+            write_component_resources(name, template)
+
+        # Bundle CSS files in template dir
+        template_dir = pathlib.Path(inspect.getfile(template)).parent
+        dest_dir = BUNDLE_DIR / name.lower()
+        dest_dir.mkdir(parents=True, exist_ok=True)
+        for css in glob.glob(str(template_dir / '*.css')):
+            shutil.copyfile(css, dest_dir / os.path.basename(css))
+
+        # Bundle Template._css
+        template_css = template._css
+        if not isinstance(template_css, list):
+            template_css = [template_css] if template_css else []
+        for css in template_css:
+            tmpl_name = name.lower()
+            for cls in template.__mro__[1:]:
+                if not issubclass(cls, BasicTemplate):
+                    continue
+                tmpl_css = cls._css if isinstance(cls._css, list) else [cls._css]
+                if css in tmpl_css:
+                    tmpl_name = cls.__name__.lower()
+            tmpl_dest_dir = BUNDLE_DIR / tmpl_name
+            tmpl_dest_dir.mkdir(parents=True, exist_ok=True)
+            shutil.copyfile(css, tmpl_dest_dir / os.path.basename(css))
+
+        # Bundle Template._js
+        template_js = template._js
+        if not isinstance(template_js, list):
+            template_js = [template_js] if template_js else []
+        for js in template_js:
+            tmpl_name = name.lower()
+            for cls in template.__mro__[1:]:
+                if not issubclass(cls, BasicTemplate):
+                    continue
+                tmpl_js = cls._js if isinstance(cls._js, list) else [cls._js]
+                if js in tmpl_js:
+                    tmpl_name = cls.__name__.lower()
+            tmpl_dest_dir = BUNDLE_DIR / tmpl_name
+            shutil.copyfile(js, tmpl_dest_dir / os.path.basename(js))
+
+
+def bundle_themes(verbose=False, external=True):
+    # Bundle design stylesheets
+    for name, design in param.concrete_descendents(Design).items():
+        if verbose:
+            print(f'Bundling {name} design resources')
+
+        # Bundle Design._resources
+        if design._resources.get('bundle', True) and external:
+            write_component_resources(name, design)
+
+    theme_bundle_dir = BUNDLE_DIR / 'theme'
+    theme_bundle_dir.mkdir(parents=True, exist_ok=True)
+    for design_css in glob.glob(str(BASE_DIR / 'theme' / 'css' / '*.css')):
+        shutil.copyfile(design_css, theme_bundle_dir / os.path.basename(design_css))
+
+
+def bundle_models(verbose=False, external=True):
+    for imp in panel_extension._imports.values():
+        if imp.startswith('panel.models'):
+            __import__(imp)
+
+    if not external:
+        return
 
     # Extract Model dependencies
     js_files, css_files, resource_files = {}, {}, {}
@@ -256,91 +287,29 @@ def bundle_resources(verbose=False):
         if verbose:
             print(f'Bundling {name} model JS resources')
         if isinstance(jsfiles, dict):
-            write_bundled_tarball(name, jsfiles, bundle_dir)
+            write_bundled_tarball(jsfiles, name=name)
         else:
-            write_bundled_files(name, jsfiles, bundle_dir)
+            write_bundled_files(name, jsfiles)
 
     for name, cssfiles in css_files.items():
         if verbose:
             print(f'Bundling {name} model CSS resources')
-        write_bundled_files(name, cssfiles, bundle_dir)
+        write_bundled_files(name, cssfiles)
 
     for name, res_files in resource_files.items():
-        write_bundled_files(name, res_files, bundle_dir)
-
-    # Bundle Template resources
-    for name, template in param.concrete_descendents(BasicTemplate).items():
-        if verbose:
-            print(f'Bundling {name} resources')
-        # Bundle Template._resources
-        if template._resources.get('bundle', True):
-            write_bundled_files(name, list(template._resources.get('css', {}).values()), bundle_dir, 'css')
-            write_bundled_files(name, list(template._resources.get('js', {}).values()), bundle_dir, 'js')
-            js_modules = []
-            for tar_name, js_module in template._resources.get('js_modules', {}).items():
-                if tar_name not in template._resources.get('tarball', {}):
-                    js_modules.append(js_module)
-            write_bundled_files(name, js_modules, bundle_dir, 'js', ext='mjs')
-            for tarball in template._resources.get('tarball', {}).values():
-                write_bundled_tarball('js', tarball, bundle_dir)
-
-        # Bundle CSS files in template dir
-        template_dir = pathlib.Path(inspect.getfile(template)).parent
-        dest_dir = bundle_dir / name.lower()
-        dest_dir.mkdir(parents=True, exist_ok=True)
-        for css in glob.glob(str(template_dir / '*.css')):
-            shutil.copyfile(css, dest_dir / os.path.basename(css))
-
-        # Bundle Template._css
-        template_css = template._css
-        if not isinstance(template_css, list):
-            template_css = [template_css] if template_css else []
-        for css in template_css:
-            tmpl_name = name.lower()
-            for cls in template.__mro__[1:-5]:
-                tmpl_css = cls._css if isinstance(cls._css, list) else [cls._css]
-                if css in tmpl_css:
-                    tmpl_name = cls.__name__.lower()
-            tmpl_dest_dir = bundle_dir / tmpl_name
-            tmpl_dest_dir.mkdir(parents=True, exist_ok=True)
-            shutil.copyfile(css, tmpl_dest_dir / os.path.basename(css))
-
-        # Bundle Template._js
-        template_js = template._js
-        if not isinstance(template_js, list):
-            template_js = [template_js] if template_js else []
-        for js in template_js:
-            tmpl_name = name.lower()
-            for cls in template.__mro__[1:-5]:
-                tmpl_js = cls._js if isinstance(cls._js, list) else [cls._js]
-                if js in tmpl_js:
-                    tmpl_name = cls.__name__.lower()
-            tmpl_dest_dir = bundle_dir / tmpl_name
-            shutil.copyfile(js, tmpl_dest_dir / os.path.basename(js))
-
-    # Bundle base themes
-    dest_dir = bundle_dir / 'theme'
-    theme_dir = pathlib.Path(inspect.getfile(Theme)).parent
-    dest_dir.mkdir(parents=True, exist_ok=True)
-    for css in glob.glob(str(theme_dir / '*.css')):
-        shutil.copyfile(css, dest_dir / os.path.basename(css))
-
-    # Bundle Theme classes
-    for name, theme in param.concrete_descendents(Theme).items():
-        if verbose:
-            print(f'Bundling {name} theme resources')
-        if theme.base_css:
-            theme_bundle_dir = bundle_dir / theme.param.base_css.owner.__name__.lower()
-            theme_bundle_dir.mkdir(parents=True, exist_ok=True)
-            shutil.copyfile(theme.base_css, theme_bundle_dir / os.path.basename(theme.base_css))
-        if theme.css:
-            tmplt_bundle_dir = bundle_dir / theme._template.__name__.lower()
-            tmplt_bundle_dir.mkdir(parents=True, exist_ok=True)
-            shutil.copyfile(theme.css, tmplt_bundle_dir / os.path.basename(theme.css))
+        write_bundled_files(name, res_files)
 
+def bundle_icons(verbose=False, external=True):
     # Bundle icons & images
-    dest_dir = bundle_dir / 'images'
+    dest_dir = BUNDLE_DIR / 'images'
     dest_dir.mkdir(parents=True, exist_ok=True)
     icon_dir = pathlib.Path(__file__).parent.parent / 'doc' / '_static' / 'icons'
     for icon in glob.glob(str(icon_dir / '*')):
         shutil.copyfile(icon, dest_dir / os.path.basename(icon))
+
+def bundle_resources(verbose=False, external=True):
+    bundle_resource_urls(verbose=verbose, external=external)
+    bundle_models(verbose=verbose, external=external)
+    bundle_templates(verbose=verbose, external=external)
+    bundle_themes(verbose=verbose, external=external)
+    bundle_icons(verbose=verbose, external=external)
