@@ -70,6 +70,8 @@ def autoreload_watcher():
     Installs a periodic callback which checks for changes in watched
     files and sys.modules.
     """
+    if not state.curdoc or not state.curdoc.session_context.server_context:
+        return
     cb = partial(_reload_on_update, {})
     _callbacks[state.curdoc] = pcb = PeriodicCallback(callback=cb, background=True)
     pcb.start()
@@ -147,7 +149,7 @@ def _reload_on_update(modify_times):
         # in the standard library), and occasionally this can cause strange
         # failures in getattr.  Just ignore anything that's not an ordinary
         # module.
-        if not module_name in sys.modules:
+        if module_name not in sys.modules:
             continue
         module = sys.modules[module_name]
         if not isinstance(module, types.ModuleType):
