@@ -1,19 +1,23 @@
+import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import * as p from "@bokehjs/core/properties"
+import {Attrs} from "@bokehjs/core/types"
 import {Markup} from "@bokehjs/models/widgets/markup"
-import {ModelEvent, JSON} from "@bokehjs/core/bokeh_events"
-import {PanelMarkupView} from "./layout"
+import {PanelMarkupView} from "./layout";
 import {serializeEvent} from "./event-to-object";
 
-export class DOMEvent extends ModelEvent {
-  event_name: string = "dom_event"
 
+export class DOMEvent extends ModelEvent {
   constructor(readonly node: string, readonly data: any) {
     super()
   }
 
-  protected _to_json(): JSON {
+  protected get event_values(): Attrs {
     return {model: this.origin, node: this.node, data: this.data}
   }
+
+  static {
+    this.prototype.event_name = "dom_event"
+  }
 }
 
 export function htmlDecode(input: string): string | null {
@@ -44,17 +48,55 @@ export class HTMLView extends PanelMarkupView {
     })
   }
 
+  protected rerender() {
+    this.render()
+    this.invalidate_layout()
+  }
+
   render(): void {
     super.render()
-    const decoded = htmlDecode(this.model.text);
-    const html = decoded || this.model.text
-    if (!html) {
-      this.markup_el.innerHTML = '';
-      return;
+    this.shadow_el.appendChild(this.container)
+
+    if (this.provider.status == "failed" || this.provider.status == "loaded")
+      this._has_finished = true
+
+    const html = this.process_tex()
+    if (html) {
+      this.container.innerHTML = html
+      if (this.model.run_scripts)
+	runScripts(this.container)
+      this._setup_event_listeners()
     }
-    this.markup_el.innerHTML = html
-    runScripts(this.markup_el)
-    this._setup_event_listeners()
+  }
+
+  process_tex(): string {
+    const decoded = htmlDecode(this.model.text);
+    const text = decoded || this.model.text
+    if (this.model.disable_math || !this.contains_tex(text))
+      return text
+
+    const tex_parts = this.provider.MathJax.find_tex(text)
+    const processed_text: string[] = []
+
+    let last_index: number | undefined = 0
+    for (const part of tex_parts) {
+      processed_text.push(text.slice(last_index, part.start.n))
+      processed_text.push(this.provider.MathJax.tex2svg(part.math, {display: part.display}).outerHTML)
+
+      last_index = part.end.n
+    }
+
+    if (last_index! < text.length)
+      processed_text.push(text.slice(last_index))
+
+    return processed_text.join("")
+  }
+
+  private contains_tex(html: string): boolean {
+    if (!this.provider.MathJax)
+      return false
+
+    return this.provider.MathJax.find_tex(html).length > 0
   }
 
   private _remove_event_listeners(): void {
@@ -97,6 +139,7 @@ export namespace HTML {
 
   export type Props = Markup.Props & {
     events: p.Property<any>
+    run_scripts: p.Property<boolean>
   }
 }
 
@@ -111,10 +154,11 @@ export class HTML extends Markup {
 
   static __module__ = "panel.models.markup"
 
-  static init_HTML(): void {
+  static {
     this.prototype.default_view = HTMLView
-    this.define<HTML.Props>(({Any}) => ({
-      events: [ Any, {} ]
+    this.define<HTML.Props>(({Any, Boolean}) => ({
+      events: [ Any, {} ],
+      run_scripts: [ Boolean, true ]
     }))
   }
 }
