@@ -1,13 +1,12 @@
+import {InlineStyleSheet, StyleSheetLike} from "@bokehjs/core/dom"
 import * as p from "@bokehjs/core/properties"
-import {HTMLBox} from "@bokehjs/models/layouts/html_box"
 
-import {PanelHTMLBoxView} from "./layout"
+import {HTMLBox, HTMLBoxView} from "./layout"
 
 const Jupyter = (window as any).Jupyter
 
-export class IPyWidgetView extends PanelHTMLBoxView {
+export class IPyWidgetView extends HTMLBoxView {
   model: IPyWidget
-  private rendered: boolean = false
   private ipyview: any
   private ipychildren: any[]
   private manager: any
@@ -38,21 +37,35 @@ export class IPyWidgetView extends PanelHTMLBoxView {
     }
   }
 
+  protected _ipy_stylesheets(): StyleSheetLike[] {
+    const stylesheets: StyleSheetLike[] = []
+
+    for (const child of document.head.children) {
+      if (child instanceof HTMLStyleElement) {
+        const raw_css = child.textContent
+        if (raw_css != null) {
+          const css = raw_css.replace(/:root/g, ":host")
+          stylesheets.push(new InlineStyleSheet(css))
+        }
+      }
+    }
+
+    return stylesheets
+  }
+
+  override stylesheets(): StyleSheetLike[] {
+    return [...super.stylesheets(), ...this._ipy_stylesheets()]
+  }
+
   render(): void {
     super.render()
     if (this.ipyview != null) {
-      this.el.appendChild(this.ipyview.el)
-      if (!this.rendered) {
-	this.ipyview.trigger('displayed', this.ipyview)
-	for (const child of this.ipychildren)
-          child.trigger('displayed', child)
-      }
+      this.shadow_el.appendChild(this.ipyview.el)
+      this.ipyview.trigger('displayed', this.ipyview)
+      for (const child of this.ipychildren)
+        child.trigger('displayed', child)
+      this.invalidate_layout()
     }
-    this.rendered = true
-  }
-
-  has_finished(): boolean {
-    return this.rendered && super.has_finished()
   }
 }
 
@@ -74,7 +87,7 @@ export class IPyWidget extends HTMLBox {
 
   static __module__ = "panel.models.ipywidget"
 
-  static init_IPyWidget(): void {
+  static {
     this.prototype.default_view = IPyWidgetView
 
     this.define<IPyWidget.Props>(({Any}) => ({
