@@ -1,23 +1,17 @@
 import * as p from "@bokehjs/core/properties"
 import { div } from "@bokehjs/core/dom"
-import {HTMLBox} from "@bokehjs/models/layouts/html_box"
 
-import {PanelHTMLBoxView} from "./layout"
+import {HTMLBox, HTMLBoxView} from "./layout"
 
-export class QuillInputView extends PanelHTMLBoxView {
+export class QuillInputView extends HTMLBoxView {
   override model: QuillInput
-  protected _container: HTMLDivElement
+  protected container: HTMLDivElement
   protected _editor: HTMLDivElement
   protected _editing: boolean
   protected _toolbar: HTMLDivElement | null
 
   quill: any
 
-  initialize(): void {
-    super.initialize()
-    this._container = div({})
-  }
-
   connect_signals(): void {
     super.connect_signals()
     this.connect(this.model.properties.disabled.change, () => this.quill.enable(!this.model.disabled))
@@ -53,9 +47,10 @@ export class QuillInputView extends PanelHTMLBoxView {
 
   render(): void {
     super.render()
-    this.el.appendChild(this._container)
+    this.container = div({})
+    this.shadow_el.appendChild(this.container)
     const theme = (this.model.mode === 'bubble') ? 'bubble' : 'snow'
-    this.quill = new (window as any).Quill(this._container, {
+    this.quill = new (window as any).Quill(this.container, {
       modules: {
         toolbar: this.model.toolbar
       },
@@ -63,8 +58,8 @@ export class QuillInputView extends PanelHTMLBoxView {
       placeholder: this.model.placeholder,
       theme: theme
     });
-    this._editor = (this.el.querySelector('.ql-editor') as HTMLDivElement)
-    this._toolbar = (this.el.querySelector('.ql-toolbar') as HTMLDivElement)
+    this._editor = (this.shadow_el.querySelector('.ql-editor') as HTMLDivElement)
+    this._toolbar = (this.shadow_el.querySelector('.ql-toolbar') as HTMLDivElement)
     this.quill.clipboard.dangerouslyPasteHTML(this.model.text)
     this.quill.on('text-change', () => {
       if (this._editing)
@@ -75,6 +70,11 @@ export class QuillInputView extends PanelHTMLBoxView {
     });
     if (!this.model.disabled)
       this.quill.enable(!this.model.disabled)
+
+    document.addEventListener("selectionchange", (..._args: any[]) => {
+      // Update selection and some other properties
+      this.quill.selection.update()
+    });
   }
 
   after_layout(): void {
@@ -105,7 +105,7 @@ export class QuillInput extends HTMLBox {
 
   static __module__ = "panel.models.quill"
 
-  static init_QuillInput(): void {
+  static {
     this.prototype.default_view = QuillInputView
 
     this.define<QuillInput.Props>(({Any, String}) => ({
