@@ -283,7 +283,7 @@ export class DataTabulatorView extends HTMLBoxView {
   tabulator: any;
   columns: Map<string, any> = new Map();
   _tabulator_cell_updating: boolean=false
-  _updating_page: boolean = true
+  _updating_page: boolean = false
   _updating_sort: boolean = false
   _selection_updating: boolean = false
   _initializing: boolean
@@ -341,9 +341,11 @@ export class DataTabulatorView extends HTMLBoxView {
       if (!this._updating_page)
         this.setPage()
     })
+    this.connect(p.visible.change, () => this.setVisibility())
     this.connect(p.max_page.change, () => this.setMaxPage())
     this.connect(p.frozen_rows.change, () => this.setFrozen())
     this.connect(p.sorters.change, () => this.setSorters())
+    this.connect(p.theme_classes.change, () => this.setCSSClasses(this.tabulator.element))
     this.connect(this.model.source.properties.data.change, () => this.setData())
     this.connect(this.model.source.streaming, () => this.addData())
     this.connect(this.model.source.patching, () => {
@@ -407,21 +409,31 @@ export class DataTabulatorView extends HTMLBoxView {
     this._initializing = false
   }
 
+  setCSSClasses(el: HTMLDivElement): void {
+    el.className = "pnx-tabulator tabulator"
+    for (const cls of this.model.theme_classes)
+      el.classList.add(cls)
+  }
+
   render(): void {
     super.render()
     this._initializing = true
     const container = div({style: "display: contents;"})
-    const el = div({class: "pnx-tabulator", style: "width: 100%; height: 100%"})
+    const el = div({style: "width: 100%; height: 100%; visibility: hidden;"})
+    this.setCSSClasses(el)
     container.appendChild(el)
     this.shadow_el.appendChild(container)
 
     let configuration = this.getConfiguration()
     this.tabulator = new Tabulator(el, configuration)
+    console.log(el, this.tabulator)
     this.watch_stylesheets()
     this.init_callbacks()
   }
 
   style_redraw(): void {
+    if (this.model.visible)
+      this.tabulator.element.style.visibility = 'visible';
     if (!this._initializing && !this._building)
       this.redraw()
   }
@@ -892,6 +904,12 @@ export class DataTabulatorView extends HTMLBoxView {
     }
   }
 
+  setVisibility(): void {
+    if (this.tabulator == null)
+      return
+    this.tabulator.element.style.visibility = this.model.visible ? 'visible' : 'hidden';
+  }
+
   updatePage(pageno: number): void {
     if (this.model.pagination === 'local' && this.model.page !== pageno) {
       this._updating_page = true
@@ -960,6 +978,7 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   setPage(): void {
+    console.log(Math.min(this.model.max_page, this.model.page))
     this.tabulator.setPage(Math.min(this.model.max_page, this.model.page))
     if (this.model.pagination === "local") {
       this.renderChildren()
@@ -1117,6 +1136,7 @@ export namespace DataTabulator {
     source: p.Property<ColumnDataSource>
     sorters: p.Property<any[]>
     cell_styles: p.Property<any>
+    theme_classes: p.Property<string[]>
   }
 }
 
@@ -1161,6 +1181,7 @@ export class DataTabulator extends HTMLBox {
       source:         [ Ref(ColumnDataSource)       ],
       sorters:        [ Array(Any),              [] ],
       cell_styles:    [ Any,                     {} ],
+      theme_classes:  [ Array(String),           [] ],
     }))
   }
 }
