@@ -1,17 +1,19 @@
 import os
 
+import pytest
+
 from panel.io.location import Location
 from panel.io.reload import (
-     _check_file, _modules, _reload_on_update, _watched_files,
-    in_blacklist, record_modules, watch
+    _check_file, _modules, _reload_on_update, _watched_files, in_blacklist,
+    record_modules, watch,
 )
 from panel.io.state import state
 
 
 def test_record_modules_not_stdlib():
     with record_modules():
-        import audioop # noqa
-    assert (_modules == set() or _modules == set('audioop'))
+        import audioop  # noqa
+    assert ((_modules == set()) or (_modules == set(['audioop'])))
     _modules.clear()
 
 def test_check_file():
@@ -34,6 +36,7 @@ def test_watch():
     # Cleanup
     _watched_files.clear()
 
+@pytest.mark.flaky(max_runs=3)
 def test_reload_on_update():
     location = Location()
     state._location = location
