@@ -48,7 +48,7 @@ def test_save_inline_resources():
     alert.save(sio, resources='inline')
     sio.seek(0)
     html = sio.read()
-    assert '.bk.alert-primary' in html
+    assert 'alert-primary' in html
 
 
 def test_save_cdn_resources():
@@ -58,7 +58,7 @@ def test_save_cdn_resources():
     alert.save(sio, resources='cdn')
     sio.seek(0)
     html = sio.read()
-    assert re.findall('https://cdn.holoviz.org/panel/(.*)/dist/css/alerts.css', html)
+    assert re.findall('https://cdn.holoviz.org/panel/(.*)/dist/panel.min.js', html)
 
 
 @hv_available
@@ -72,4 +72,3 @@ def test_static_path_in_holoviews_save(tmpdir):
     content = out_file.read_text()
 
     assert 'src="/static/js/bokeh' in content and 'src="static/js/bokeh' not in content
-    assert 'href="/static/extensions/panel/css/' in content and 'href="static/extensions/panel/css/' not in content
