@@ -1,6 +1,8 @@
 import pytest
 
 from panel.depends import bind, param_value_if_widget
+from panel.pane import panel
+from panel.param import ParamFunction
 from panel.widgets import IntSlider
 
 
@@ -150,3 +152,21 @@ def test_bind_bound_function_to_kwarg():
     widget.value = 3
 
     assert bound_function() == 2
+
+
+def test_bind_bare_emits_warning(caplog):
+
+    def foo():
+        return 'bar'
+
+    ParamFunction(foo)
+
+    # Emits a Param warning
+    panel(bind(foo))
+
+    found = False
+    for log_record in caplog.records:
+        if (log_record.levelname == 'WARNING' and
+           "The function 'foo' does not have any dependencies and will never update" in log_record.message):
+            found = True
+    assert found
