@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import asyncio
 import unittest.mock
 
 from functools import partial
@@ -162,7 +163,6 @@ def test_text_input_controls():
     assert not len(params1 - params2)
     assert not len(params2 - params1)
 
-
 def test_pass_widget_by_reference():
     int_input = IntInput(start=0, end=400, value=42)
     text_input = TextInput(width=int_input)
@@ -173,7 +173,6 @@ def test_pass_widget_by_reference():
 
     assert text_input.width == 101
 
-
 def test_pass_param_by_reference():
     int_input = IntInput(start=0, end=400, value=42)
     text_input = TextInput(width=int_input.param.value)
@@ -184,7 +183,6 @@ def test_pass_param_by_reference():
 
     assert text_input.width == 101
 
-
 def test_pass_bind_function_by_reference():
     int_input = IntInput(start=0, end=400, value=42)
     fn = bind(lambda v: v + 10, int_input)
@@ -196,6 +194,98 @@ def test_pass_bind_function_by_reference():
 
     assert text_input.width == 111
 
+def test_pass_bind_generator_by_reference():
+    int_input = IntInput(start=0, end=400, value=42)
+
+    def gen(v):
+        yield v + 10
+
+    text_input = TextInput(width=bind(gen, int_input))
+
+    assert text_input.width == 52
+
+    int_input.value = 101
+
+    assert text_input.width == 111
+
+def test_pass_bind_multi_generator_by_reference():
+    int_input = IntInput(start=0, end=400, value=42)
+
+    def gen(v):
+        yield v + 10
+        yield v + 20
+
+    text_input = TextInput(width=bind(gen, int_input))
+
+    widths = []
+    text_input.param.watch(lambda e: widths.append(e.new), 'width')
+
+    assert text_input.width == 62
+
+    int_input.value = 101
+
+    assert widths == [111, 121]
+    assert text_input.width == 121
+
+@pytest.mark.asyncio
+async def test_pass_bind_async_generator_by_reference():
+    int_input = IntInput(start=0, end=400, value=42)
+
+    async def gen(v):
+        yield v + 10
+
+    text_input = TextInput(width=bind(gen, int_input))
+
+    await asyncio.sleep(0.01)
+    assert text_input.width == 52
+
+    int_input.value = 101
+
+    await asyncio.sleep(0.01)
+    assert text_input.width == 111
+
+@pytest.mark.asyncio
+async def test_pass_bind_multi_async_generator_by_reference():
+    int_input = IntInput(start=0, end=400, value=42)
+
+    async def gen(v):
+        yield v + 10
+        yield v + 20
+
+    text_input = TextInput(width=bind(gen, int_input))
+
+    widths = []
+    text_input.param.watch(lambda e: widths.append(e.new), 'width')
+
+    await asyncio.sleep(0.01)
+    assert text_input.width == 62
+
+    int_input.value = 101
+
+    await asyncio.sleep(0.01)
+    assert widths == [52, 62, 111, 121]
+    assert text_input.width == 121
+
+
+@pytest.mark.asyncio
+async def test_pass_bind_multi_async_generator_by_reference_and_abort():
+    int_input = IntInput(start=0, end=400, value=42)
+
+    async def gen(v):
+        yield v + 10
+        await asyncio.sleep(0.1)
+        yield v + 20
+
+    text_input = TextInput(width=bind(gen, int_input))
+
+    await asyncio.sleep(0.01)
+    assert text_input.width == 52
+    int_input.value = 101
+    await asyncio.sleep(0.01)
+    assert text_input.width == 111
+    await asyncio.sleep(0.1)
+    assert text_input.width == 121
+
 def test_pass_parameterized_method_by_reference():
 
     class Test(param.Parameterized):
