@@ -16,10 +16,10 @@ def test_update_markdown_pane(page, port):
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
 
-    assert page.text_content(".bk.markdown") == 'Initial'
+    assert page.locator(".markdown").locator("div").text_content() == 'Initial\n'
     md.object = 'Updated'
     time.sleep(0.1)
-    assert page.text_content(".bk.markdown") == 'Updated'
+    assert page.locator(".markdown").locator("div").text_content() == 'Updated\n'
 
 
 def test_update_markdown_pane_resizes(page, port):
@@ -30,10 +30,12 @@ def test_update_markdown_pane_resizes(page, port):
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
 
-    assert page.locator(".bk.markdown").bounding_box()['height'] == 45
+    height = page.locator(".markdown").bounding_box()['height']
+    assert int(height) == 18
     md.object = """
     - Bullet
     - Points
     """
     time.sleep(0.1)
-    assert page.locator(".bk.markdown").bounding_box()['height'] == 64
+    height = page.locator(".markdown").bounding_box()['height']
+    assert int(height) == 37
