@@ -124,7 +124,7 @@ def test_select_change_groups(document, comm):
     assert widget.options == {'C': [('4', 'd')], 'D': [('5', 'e'), ('6', 'f')]}
 
     select.groups = {}
-    assert select.value == None
+    assert select.value is None
     assert widget.value == ''
 
 
@@ -158,7 +158,7 @@ def test_select_change_options(document, comm):
     assert widget.value == str(opts['A'])
 
     select.options = {}
-    assert select.value == None
+    assert select.value is None
     assert widget.value == ''
 
 
@@ -290,7 +290,7 @@ def test_select_disabled_options_error_set_disabled_options(options, size):
 @pytest.mark.parametrize('size', [1, 2], ids=['size=1', 'size>1'])
 def test_select_disabled_options_set_value_and_disabled_options(options, size, document, comm):
     select = Select(options=options, disabled_options=[20], size=size)
-    select.param.set_param(value=20, disabled_options=[10])
+    select.param.update(value=20, disabled_options=[10])
 
     widget = select.get_root(document, comm=comm)
 
@@ -460,7 +460,7 @@ def test_cross_select_constructor():
     assert cross_select._lists[False].size == 5
 
     # Query unselected item
-    cross_select._search[False].value = 'D'
+    cross_select._search[False].value_input = 'D'
     assert cross_select._lists[False].value == ['D']
 
     # Move queried item
@@ -471,14 +471,14 @@ def test_cross_select_constructor():
     assert cross_select._lists[False].value == []
 
     # Query selected item
-    cross_select._search[True].value = 'D'
+    cross_select._search[True].value_input = 'D'
     cross_select._buttons[False].param.trigger('clicks')
     assert cross_select._lists[False].options == ['D', '4']
     assert cross_select._lists[False].value == ['D']
     assert cross_select._lists[True].options == []
 
     # Clear query
-    cross_select._search[False].value = ''
+    cross_select._search[False].value_input = ''
     assert cross_select._lists[False].value == []
 
 
