@@ -34,12 +34,13 @@ https://panel.holoviz.org/getting_started/index.html
 """
 from .base import CompositeWidget, Widget  # noqa
 from .button import Button, MenuButton, Toggle  # noqa
+from .chatbox import ChatBox  # noqa
 from .codeeditor import Ace, CodeEditor  # noqa
 from .debugger import Debugger  # noqa
 from .file_selector import FileSelector  # noqa
 from .indicators import (  # noqa
     BooleanStatus, Dial, Gauge, LinearGauge, LoadingSpinner, Number, Progress,
-    Tqdm, Trend,
+    TooltipIcon, Tqdm, Trend,
 )
 from .input import (  # noqa
     ArrayInput, Checkbox, ColorPicker, DatePicker, DatetimeInput,
@@ -72,6 +73,7 @@ __all__ = (
     "AutocompleteInput",
     "BooleanStatus",
     "Button",
+    "ChatBox",
     "Checkbox",
     "CheckBoxGroup",
     "CheckButtonGroup",
@@ -125,6 +127,7 @@ __all__ = (
     "SpeechToText",
     "Spinner",
     "StaticText",
+    "Switch",
     "Tabulator",
     "Terminal",
     "TextAreaInput",
@@ -133,6 +136,7 @@ __all__ = (
     "TextToSpeech",
     "Toggle",
     "ToggleGroup",
+    "TooltipIcon",
     "Tqdm",
     "Trend",
     "Utterance",
