@@ -2,16 +2,22 @@
 Defines a FileSelector widget which allows selecting files and
 directories on the server.
 """
+from __future__ import annotations
+
 import os
 
 from collections import OrderedDict
 from fnmatch import fnmatch
-from typing import AnyStr, List, Tuple, Union
+from typing import (
+    AnyStr, ClassVar, List, Optional, Tuple, Type,
+)
 
 import param
 
 from ..io import PeriodicCallback
-from ..layout import Column, Divider, Row
+from ..layout import (
+    Column, Divider, ListPanel, Row,
+)
 from ..util import fullpath
 from ..viewable import Layoutable
 from .base import CompositeWidget
@@ -75,11 +81,6 @@ class FileSelector(CompositeWidget):
     only_files = param.Boolean(default=False, doc="""
         Whether to only allow selecting files.""")
 
-    margin = param.Parameter(default=(5, 10, 20, 10), doc="""
-        Allows to create additional space around the component. May
-        be specified as a two-tuple of the form (vertical, horizontal)
-        or a four-tuple (top, right, bottom, left).""")
-
     show_hidden = param.Boolean(default=False, doc="""
         Whether to show hidden files and directories (starting with
         a period).""")
@@ -99,9 +100,9 @@ class FileSelector(CompositeWidget):
     value = param.List(default=[], doc="""
         List of selected files.""")
 
-    _composite_type = Column
+    _composite_type: ClassVar[Type[ListPanel]] = Column
 
-    def __init__(self, directory: Union[AnyStr, os.PathLike]=None, **params):
+    def __init__(self, directory: AnyStr | os.PathLike | None = None, **params):
         from ..pane import Markdown
         if directory is not None:
             params['directory'] = fullpath(directory)
@@ -116,22 +117,25 @@ class FileSelector(CompositeWidget):
         # Set up layout
         layout = {p: getattr(self, p) for p in Layoutable.param
                   if p not in ('name', 'height', 'margin') and getattr(self, p) is not None}
-        sel_layout = dict(layout, sizing_mode='stretch_both', height=None, margin=0)
-        self._selector = CrossSelector(filter_fn=lambda p, f: fnmatch(f, p),
-                                       size=self.size, **sel_layout)
-        self._back = Button(name='◀', width=25, margin=(5, 10, 0, 0), disabled=True)
-        self._forward = Button(name='▶', width=25, margin=(5, 10), disabled=True)
-        self._up = Button(name='⬆', width=25, margin=(5, 10), disabled=True)
-        self._directory = TextInput(value=self.directory, margin=(5, 10), width_policy='max')
-        self._go = Button(name='⬇', disabled=True, width=25, margin=(5, 10, 0, 0))
-        self._reload = Button(name='↻', width=25, margin=(5, 15, 0, 10))
+        sel_layout = dict(layout, sizing_mode='stretch_width', height=300, margin=0)
+        self._selector = CrossSelector(
+            filter_fn=lambda p, f: fnmatch(f, p), size=self.size, **sel_layout
+        )
+
+        self._back = Button(name='◀', width=40, height=40, margin=(5, 10, 0, 0), disabled=True, align='center')
+        self._forward = Button(name='▶', width=40, height=40, margin=(5, 10, 0, 0), disabled=True, align='center')
+        self._up = Button(name='⬆', width=40, height=40, margin=(5, 10, 0, 0), disabled=True, align='center')
+        self._directory = TextInput(value=self.directory, margin=(5, 10, 0, 0), width_policy='max')
+        self._go = Button(name='⬇', disabled=True, width=40, height=40, margin=(5, 5, 0, 0), align='center')
+        self._reload = Button(name='↻', width=40, height=40, margin=(5, 0, 0, 10), align='center')
         self._nav_bar = Row(
             self._back, self._forward, self._up, self._directory, self._go, self._reload,
             **dict(layout, width=None, margin=0, width_policy='max')
         )
         self._composite[:] = [self._nav_bar, Divider(margin=0), self._selector]
-        self._selector._selected.insert(0, Markdown('### Selected files', margin=0))
-        self._selector._unselected.insert(0, Markdown('### File Browser', margin=0))
+        style = 'h4 { margin-block-start: 0; margin-block-end: 0;}'
+        self._selector._selected.insert(0, Markdown('#### Selected files', margin=0, stylesheets=[style]))
+        self._selector._unselected.insert(0, Markdown('#### File Browser', margin=0, stylesheets=[style]))
         self.link(self._selector, size='size')
 
         # Set up state
@@ -156,7 +160,7 @@ class FileSelector(CompositeWidget):
         if self.refresh_period:
             self._periodic.start()
 
-    def _update_periodic(self, event):
+    def _update_periodic(self, event: param.parameterized.Event):
         if event.new:
             self._periodic.period = event.new
             if not self._periodic.running:
@@ -168,12 +172,12 @@ class FileSelector(CompositeWidget):
     def _root_directory(self):
         return self.root_directory or self.directory
 
-    def _update_value(self, event):
+    def _update_value(self, event: param.parameterized.Event):
         value = [v for v in event.new if not self.only_files or os.path.isfile(v)]
         self._selector.value = value
         self.value = value
 
-    def _dir_change(self, event):
+    def _dir_change(self, event: param.parameterized.Event):
         path = fullpath(self._directory.value)
         if not path.startswith(self._root_directory):
             self._directory.value = self._root_directory
@@ -185,7 +189,9 @@ class FileSelector(CompositeWidget):
     def _refresh(self):
         self._update_files(refresh=True)
 
-    def _update_files(self, event=None, refresh=False):
+    def _update_files(
+        self, event: Optional[param.parameterized.Event] = None, refresh: bool = False
+    ):
         path = fullpath(self._directory.value)
         refresh = refresh or (event and getattr(event, 'obj', None) is self._reload)
         if refresh:
@@ -223,7 +229,7 @@ class FileSelector(CompositeWidget):
         self._selector.options = options
         self._selector.value = selected
 
-    def _filter_blacklist(self, event):
+    def _filter_blacklist(self, event: param.parameterized.Event):
         """
         Ensure that if unselecting a currently selected path and it
         is not in the current working directory then it is removed
@@ -239,7 +245,7 @@ class FileSelector(CompositeWidget):
         ])
         blacklist.options = [o for o in blacklist.options if o in paths]
 
-    def _select(self, event):
+    def _select(self, event: param.parameterized.Event):
         if len(event.new) != 1:
             self._directory.value = self._cwd
             return
@@ -251,7 +257,7 @@ class FileSelector(CompositeWidget):
         else:
             self._directory.value = self._cwd
 
-    def _go_back(self, event):
+    def _go_back(self, event: param.parameterized.Event):
         self._position -= 1
         self._directory.value = self._stack[self._position]
         self._update_files()
@@ -259,12 +265,12 @@ class FileSelector(CompositeWidget):
         if self._position == 0:
             self._back.disabled = True
 
-    def _go_forward(self, event):
+    def _go_forward(self, event: param.parameterized.Event):
         self._position += 1
         self._directory.value = self._stack[self._position]
         self._update_files()
 
-    def _go_up(self, event=None):
+    def _go_up(self, event: Optional[param.parameterized.Event] = None):
         path = self._cwd.split(os.path.sep)
         self._directory.value = os.path.sep.join(path[:-1]) or os.path.sep
         self._update_files(True)
