@@ -4,6 +4,8 @@ The Terminal Widget makes it easy to create Panel Applications with Terminals.
 - For example apps which streams the output of processes or logs.
 - For example apps which provide interactive bash, python or ipython terminals
 """
+from __future__ import annotations
+
 import os
 import select
 import shlex
@@ -11,12 +13,14 @@ import signal
 import subprocess
 import sys
 
+from typing import ClassVar, Mapping
+
 import param
 
 from pyviz_comms import JupyterComm
 
 from ..io.callbacks import PeriodicCallback
-from ..util import lazy_load
+from ..util import edit_readonly, lazy_load
 from .base import Widget
 
 
@@ -40,21 +44,21 @@ class TerminalSubprocess(param.Parameterized):
     running = param.Boolean(default=False, constant=True, doc="""
         Whether or not the subprocess is running.""")
 
-    _child_pid = param.Integer(0, doc="Child process id")
+    _child_pid = param.Integer(default=0, doc="Child process id")
 
-    _fd = param.Integer(0, doc="Child file descriptor.")
+    _fd = param.Integer(default=0, doc="Child file descriptor.")
 
-    _max_read_bytes = param.Integer(1024 * 20)
+    _max_read_bytes = param.Integer(default=1024 * 20)
 
     _periodic_callback = param.ClassSelector(class_=PeriodicCallback, doc="""
         Watches the subprocess for output""")
 
-    _period = param.Integer(50, doc="Period length of _periodic_callback")
+    _period = param.Integer(default=50, doc="Period length of _periodic_callback")
 
     _terminal = param.Parameter(constant=True, doc="""
         The Terminal to which the subprocess is connected.""")
 
-    _timeout_sec = param.Integer(0)
+    _timeout_sec = param.Integer(default=0)
 
     _watcher = param.Parameter(doc="Watches the subprocess for user input")
 
@@ -77,6 +81,7 @@ class TerminalSubprocess(param.Parameterized):
         Runs a subprocess command.
         """
         import pty
+
         # Inspiration: https://github.com/cs01/pyxtermjs
         # Inspiration: https://github.com/jupyter/terminado
         if not args:
@@ -113,23 +118,35 @@ class TerminalSubprocess(param.Parameterized):
             self._child_pid = child_pid
             self._fd = fd
 
-            # Todo: Determine if it is better to run this is seperate thread?
+            self._set_winsize()
+
             self._periodic_callback = PeriodicCallback(
                 callback=self._forward_subprocess_output_to_terminal,
-                period=self._period,
+                period=self._period
             )
             self._periodic_callback.start()
 
             self._watcher = self._terminal.param.watch(
-                self._forward_terminal_input_to_subprocess, "value"
+                self._forward_terminal_input_to_subprocess, 'value',
+                onlychanged=False
             )
             with param.edit_constant(self):
                 self.running = True
 
+    @param.depends('_terminal.ncols', '_terminal.nrows', watch=True)
+    def _set_winsize(self):
+        if self._fd is None or not self._terminal.nrows or not self._terminal.ncols:
+            return
+        import fcntl
+        import struct
+        import termios
+        winsize = struct.pack("HHHH", self._terminal.nrows, self._terminal.ncols, 0, 0)
+        try:
+            fcntl.ioctl(self._fd, termios.TIOCSWINSZ, winsize)
+        except OSError:
+            pass
+
     def _kill(self, *events):
-        """
-        Kills the subprocess.
-        """
         child_pid = self._child_pid
         self._reset()
 
@@ -154,16 +171,30 @@ class TerminalSubprocess(param.Parameterized):
     def _remove_last_line_from_string(value):
         return value[: value.rfind("CompletedProcess")]
 
+    def _decode_utf8_on_boundary(self, fd, max_read_bytes, max_extra_bytes=2):
+        "UTF-8 characters can be multi-byte so need to decode on correct boundary"
+        data = os.read(fd, max_read_bytes)
+        for _ in range(max_extra_bytes+1):
+            try:
+                return data.decode('utf-8')
+            except UnicodeDecodeError:
+                data = data + os.read(fd, 1)
+        raise UnicodeError('Could not find decode boundary for UTF-8')
+
     def _forward_subprocess_output_to_terminal(self):
-        if self._fd:
-            (data_ready, _, _) = select.select([self._fd], [], [], self._timeout_sec)
-            if data_ready:
-                output = os.read(self._fd, self._max_read_bytes).decode()
-                # If Child Process finished it will signal this by appending "CompletedProcess(...)"
-                if "CompletedProcess" in output:
-                    self._reset()
-                    output = self._remove_last_line_from_string(output)
-                self._terminal.write(output)
+        if not self._fd:
+            return
+        (data_ready, _, _) = select.select([self._fd], [], [], self._timeout_sec)
+        if not data_ready:
+            return
+
+        output = self._decode_utf8_on_boundary(self._fd, self._max_read_bytes)
+
+        # If Child Process finished it will signal this by appending "CompletedProcess(...)"
+        if "CompletedProcess" in output:
+            self._reset()
+            output = self._remove_last_line_from_string(output)
+        self._terminal.write(output)
 
     def _forward_terminal_input_to_subprocess(self, *events):
         if self._fd:
@@ -189,9 +220,17 @@ class TerminalSubprocess(param.Parameterized):
 
 class Terminal(Widget):
     """
-    The Terminal widget renders a live terminal in the browser using
+    The `Terminal` widget renders a live terminal in the browser using
     the xterm.js library making it possible to display logs or even
     provide an interactive terminal in a Panel application.
+
+    Reference: https://panel.holoviz.org/reference/widgets/Terminal.html
+
+    :Example:
+
+    >>> Terminal(
+    ...     "Welcome to the Panel Terminal!", options={"cursorBlink": True}
+    ... )
     """
 
     clear = param.Action(doc="Clears the Terminal.", constant=True)
@@ -203,47 +242,45 @@ class Terminal(Widget):
     output = param.String(default="", doc="""
         System output written to the Terminal""")
 
+    ncols = param.Integer(readonly=True, doc="""
+        The number of columns in the terminal.""")
+
+    nrows = param.Integer(readonly=True, doc="""
+        The number of rows in the terminal.""")
+
     value = param.String(label="Input", readonly=True, doc="""
         User input received from the Terminal. Sent one character at the time.""")
 
     write_to_console = param.Boolean(default=False, doc="""
-        Weather or not to write to the server console. Default is False""")
+        Whether or not to write to the server console.""")
 
     _clears = param.Integer(doc="Sends a signal to clear the terminal")
 
     _output = param.String(default="")
-    
-    _value_repeats = param.Integer(
-        doc="""
-        Hack: Sends a signal that the value has been repeated."""
-    )
 
-    _rename = {
-        "clear": None,
-        "output": None,
-        "_output": "output",
-        "value": "input",
-        "write_to_console": None,
+    _rename: ClassVar[Mapping[str, str | None]] = {
+        'clear': None, 'name': None, 'output': None, '_output': 'output',
+        'value': None, 'write_to_console': None,
     }
 
     def __init__(self, output=None, **params):
-        params['_output'] = output = output or ""
+        params['_output'] = output = output or ''
         params['clear'] = self._clear
         super().__init__(output=output, **params)
         self._subprocess = None
 
-    def write(self, __s, ):
+    def write(self, __s):
         cleaned = __s
         if isinstance(__s, str):
             cleaned = __s
         elif isinstance(__s, bytes):
-            cleaned = __s.decode("utf8")
+            cleaned = __s.decode('utf8')
         else:
             cleaned = str(__s)
 
-        if self.output == cleaned:
+        if self._output == cleaned:
             # Hack to support writing the same string multiple times in a row
-            self._output = ""
+            self._output = ''
 
         self._output = cleaned
         self.output += cleaned
@@ -252,30 +289,33 @@ class Terminal(Widget):
     def _get_model(self, doc, root=None, parent=None, comm=None):
         if self._widget_type is None:
             self._widget_type = lazy_load(
-                'panel.models.terminal', 'Terminal', isinstance(comm, JupyterComm)
+                'panel.models.terminal', 'Terminal', isinstance(comm, JupyterComm), root
             )
         model = super()._get_model(doc, root, parent, comm)
         model.output = self.output
+        self._register_events('keystroke', model=model, doc=doc, comm=comm)
         return model
 
+    def _process_event(self, event):
+        with edit_readonly(self):
+            self.value = event.key
+            with param.discard_events(self):
+                self.value = ''
+
     def _clear(self, *events):
         """
         Clears all output on the terminal.
         """
-        self.output = ""
+        self.output = ''
         self._clears += 1
 
-    @param.depends("_output", watch=True)
+    @param.depends('_output', watch=True)
     def _write(self):
         if self.write_to_console:
             sys.__stdout__.write(self._output)
 
-    @param.depends("_value_repeats", watch=True)
-    def _repeat_value_hack(self):
-        self.param.trigger('value')
-
     def __repr__(self, depth=None):
-        return f"Terminal(id={id(self)})"
+        return f'Terminal(id={id(self)})'
 
     @property
     def subprocess(self):
